@@ -12,6 +12,6 @@ __all__ = [
     "TokenUpdated",
 ]
 
-__version__ = "0.0.2"
+__version__ = "0.0.5"
 
-logging.getLogger("requests_oauthlib").addHandler(logging.NullHandler())
+logging.getLogger("async_oauthlib").addHandler(logging.NullHandler())
